package com.sun.corba.se.impl.activation;

import com.sun.corba.se.spi.activation.RepositoryPackage.ServerDef;
import com.sun.corba.se.impl.naming.cosnaming.TransientNameService;
import com.sun.corba.se.spi.activation.ActivatorHelper;
import com.sun.corba.se.spi.activation.LocatorHelper;
import org.omg.CORBA.INTERNAL;
import org.omg.CORBA.COMM_FAILURE;
import com.sun.corba.se.impl.orbutil.CorbaResourceUtil;
import java.util.Properties;
import com.sun.corba.se.impl.transport.SocketOrChannelAcceptorImpl;
import com.sun.corba.se.impl.legacy.connection.SocketFactoryAcceptorImpl;
import com.sun.corba.se.spi.orb.ORB;
import com.sun.corba.se.spi.activation.Activator;
import com.sun.corba.se.spi.activation.Locator;
import java.io.File;

public class ORBD
{
    private int initSvcPort;
    protected File dbDir;
    private String dbDirName;
    protected Locator locator;
    protected Activator activator;
    protected RepositoryImpl repository;
    private static String[][] orbServers;
    
    public ORBD() {
    }
    
    protected void initializeBootNaming(ORB orb) {
        this.initSvcPort = orb.getORBData().getORBInitialPort();
        SocketOrChannelAcceptorImpl socketOrChannelAcceptorImpl;
        if (orb.getORBData().getLegacySocketFactory() == null) {
            socketOrChannelAcceptorImpl = new SocketOrChannelAcceptorImpl(orb, this.initSvcPort, "BOOT_NAMING", "IIOP_CLEAR_TEXT");
        }
        else {
            socketOrChannelAcceptorImpl = new SocketFactoryAcceptorImpl(orb, this.initSvcPort, "BOOT_NAMING", "IIOP_CLEAR_TEXT");
        }
        orb.getCorbaTransportManager().registerAcceptor(socketOrChannelAcceptorImpl);
    }
    
    protected ORB createORB(String[] array) {
        Properties properties = System.getProperties();
        properties.put("com.sun.CORBA.POA.ORBServerId", "1000");
        properties.put("com.sun.CORBA.POA.ORBPersistentServerPort", properties.getProperty("com.sun.CORBA.activation.Port", Integer.toString(1049)));
        properties.put("org.omg.CORBA.ORBClass", "com.sun.corba.se.impl.orb.ORBImpl");
        return (ORB)ORB.init(array, properties);
    }
    
    private void run(String[] array) {
        try {
            this.processArgs(array);
            ORB orb = this.createORB(array);
            if (orb.orbdDebugFlag) {
                System.out.println("ORBD begins initialization.");
            }
            int systemDirs = this.createSystemDirs("orb.db");
            this.startActivationObjects(orb);
            if (!(systemDirs == 0)) {
                this.installOrbServers(this.getRepository(), this.getActivator());
            }
            if (orb.orbdDebugFlag) {
                System.out.println("ORBD is ready.");
                System.out.println("ORBD serverid: " + System.getProperty("com.sun.CORBA.POA.ORBServerId"));
                System.out.println("activation dbdir: " + System.getProperty("com.sun.CORBA.activation.DbDir"));
                System.out.println("activation port: " + System.getProperty("com.sun.CORBA.activation.Port"));
                String str = System.getProperty("com.sun.CORBA.activation.ServerPollingTime");
                if (str == null) {
                    str = Integer.toString(1000);
                }
                System.out.println("activation Server Polling Time: " + str + " milli-seconds ");
                String str2 = System.getProperty("com.sun.CORBA.activation.ServerStartupDelay");
                if (str2 == null) {
                    str2 = Integer.toString(1000);
                }
                System.out.println("activation Server Startup Delay: " + str2 + " milli-seconds ");
            }
            new NameServiceStartThread(orb, this.dbDir).start();
            orb.run();
        }
        catch (COMM_FAILURE x) {
            System.out.println(CorbaResourceUtil.getText("orbd.commfailure"));
            System.out.println(x);
            x.printStackTrace();
        }
        catch (INTERNAL x2) {
            System.out.println(CorbaResourceUtil.getText("orbd.internalexception"));
            System.out.println(x2);
            x2.printStackTrace();
        }
        catch (Exception x3) {
            System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
            System.out.println(x3);
            x3.printStackTrace();
        }
    }
    
    private void processArgs(String[] array) {
        Properties properties = System.getProperties();
        for (int i = 0; i < array.length; ++i) {
            if (array[i].equals("-port")) {
                if (i + 1 < array.length) {
                    properties.put("com.sun.CORBA.activation.Port", array[++i]);
                }
                else {
                    System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
                }
            }
            else if (array[i].equals("-defaultdb")) {
                if (i + 1 < array.length) {
                    properties.put("com.sun.CORBA.activation.DbDir", array[++i]);
                }
                else {
                    System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
                }
            }
            else if (array[i].equals("-serverid")) {
                if (i + 1 < array.length) {
                    properties.put("com.sun.CORBA.POA.ORBServerId", array[++i]);
                }
                else {
                    System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
                }
            }
            else if (array[i].equals("-serverPollingTime")) {
                if (i + 1 < array.length) {
                    properties.put("com.sun.CORBA.activation.ServerPollingTime", array[++i]);
                }
                else {
                    System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
                }
            }
            else if (array[i].equals("-serverStartupDelay")) {
                if (i + 1 < array.length) {
                    properties.put("com.sun.CORBA.activation.ServerStartupDelay", array[++i]);
                }
                else {
                    System.out.println(CorbaResourceUtil.getText("orbd.usage", "orbd"));
                }
            }
        }
    }
    
    protected boolean createSystemDirs(String str) {
        boolean n = false;
        Properties properties = System.getProperties();
        this.dbDir = new File(properties.getProperty("com.sun.CORBA.activation.DbDir", properties.getProperty("user.dir") + properties.getProperty("file.separator") + str));
        properties.put("com.sun.CORBA.activation.DbDir", this.dbDirName = this.dbDir.getAbsolutePath());
        if (!this.dbDir.exists()) {
            this.dbDir.mkdir();
            n = true;
        }
        File o = new File(this.dbDir, "logs");
        if (!o.exists()) {
            o.mkdir();
        }
        return n;
    }
    
    protected File getDbDir() {
        return this.dbDir;
    }
    
    protected String getDbDirName() {
        return this.dbDirName;
    }
    
    protected void startActivationObjects(ORB orb) throws Exception {
        this.initializeBootNaming(orb);
        orb.register_initial_reference("ServerRepository", this.repository = new RepositoryImpl(orb, this.dbDir, orb.orbdDebugFlag));
        ServerManagerImpl serverManagerImpl = new ServerManagerImpl(orb, orb.getCorbaTransportManager(), this.repository, this.getDbDirName(), orb.orbdDebugFlag);
        orb.register_initial_reference("ServerLocator", this.locator = LocatorHelper.narrow(serverManagerImpl));
        orb.register_initial_reference("ServerActivator", this.activator = ActivatorHelper.narrow(serverManagerImpl));
        TransientNameService transientNameService = new TransientNameService(orb, "TNameService");
    }
    
    protected Locator getLocator() {
        return this.locator;
    }
    
    protected Activator getActivator() {
        return this.activator;
    }
    
    protected RepositoryImpl getRepository() {
        return this.repository;
    }
    
    protected void installOrbServers(RepositoryImpl repositoryImpl, Activator activator) {
        for (int i = 0; i < ORBD.orbServers.length; ++i) {
            try {
                String[] array = ORBD.orbServers[i];
                ServerDef o = new ServerDef(array[1], array[2], array[3], array[4], array[5]);
                int intValue = (int)Integer.valueOf(ORBD.orbServers[i][0]);
                repositoryImpl.registerServer(o, intValue);
                activator.activate(intValue);
            }
            catch (Exception ex) {}
        }
    }
    
    public static void main(String[] array) {
        new ORBD().run(array);
    }
    
    static {
        ORBD.orbServers = new String[][] { { "" } };
    }
}
